@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, TypedDict
 
 from .core.http import HttpClient
 
@@ -9,7 +9,14 @@ class Files:
 
     # POST /files/upload?projectID=...&container_name=...
     # body example: { "filenames": ["file.pdf"], "tags": ["resume"], "source_type": "STORAGE", "org_id": "..." }
-    def upload_request(self, project_id: str, container_name: str, body: Dict[str, Any]):
+    class UploadFilesBody(TypedDict):
+        filenames: list[str]
+        tags: list[str]
+        projectID: str
+        source_type: str
+        org_id: str
+
+    def upload_request(self, project_id: str, container_name: str, body: UploadFilesBody):
         params: Dict[str, Any] = {"projectID": project_id, "container_name": container_name}
         return self.http.request("POST", "/files/upload", params=params, json=body)
 
