@@ -1,19 +1,41 @@
 from __future__ import annotations
-from typing import Any, Dict, Optional
+from typing import Optional, TypedDict, Dict, Any
 
 from .core.http import HttpClient
 
+
+class SkillCreateBody(TypedDict):
+    """Body for creating a Skill.
+
+    Required (user_id can be null but key is required):
+      - name: str
+      - logo: str
+      - connector_name: str
+      - description: str
+      - projectID: str
+      - connector_id: str
+      - user_id: Optional[str]
+    """
+    name: str
+    logo: str
+    connector_name: str
+    description: str
+    projectID: str
+    connector_id: str
+    user_id: Optional[str]
+
+
 class Skills:
     def __init__(self, http: HttpClient):
         self.http = http
 
     # POST /skills/
-    def create(self, body: Dict[str, Any]):
+    def create(self, body: SkillCreateBody):
         return self.http.request("POST", "/skills/", json=body)
 
     # GET /skills/?projectID=...&limit=...
     def list(self, project_id: str, *, limit: Optional[int] = None):
-        params: Dict[str, Any] = {"projectID": project_id}
+        params = {"projectID": project_id}
         if limit is not None:
             params["limit"] = limit
         return self.http.request("GET", "/skills/", params=params)
